import unittest

class ViewTests(unittest.TestCase):
    def setUp(self):
        # This sets up the application registry with the registrations
        # your application declares in its configure.zcml (including
        # dependent registrations for repoze.bfg itself).  This is a
        # heavy-hammer way of making sure that your tests have enough
        # context to run properly.  But tests will run faster if you
        # use only the registrations you need programmatically, so you
        # should explore ways to do that rather than rely on ZCML (see
        # the repoze.bfg tests for inspiration).
        self._cleanup()
        import bestappever
        import zope.configuration.xmlconfig
        zope.configuration.xmlconfig.file('configure.zcml',
                                          package=bestappever)

    def tearDown(self):
        self._cleanup()

    def _cleanup(self):
        # this clears the application registry 
        from zope.testing.cleanup import cleanUp
        cleanUp()
        
    def test_my_view(self):
        from bestappever.views import my_view
        context = DummyContext()
        request = DummyRequest()
        result = my_view(context, request)
        self.assertEqual(result.status, '200 OK')
        body = result.app_iter[0]
        self.failUnless('Welcome to bestappever' in body)
        self.assertEqual(len(result.headerlist), 2)
        self.assertEqual(result.headerlist[0],
                         ('content-type', 'text/html; charset=UTF-8'))
        self.assertEqual(result.headerlist[1], ('Content-Length',
                                                str(len(body))))

class DummyContext:
    pass

class DummyRequest:
    pass



from repoze.bfg.template import render_template_to_response

def my_view(context, request):
    return render_template_to_response('templates/mytemplate.pt',
                                       project = 'bestappever',
                                       abspath = context.absolute_path(),
                                       name = context.__name__)



from repoze.bfg import make_app
from repoze.bfg import get_options

def app(global_config, **kw):
    # paster app config callback
    from bestappever.models import get_root
    import bestappever
    return make_app(get_root, bestappever, options=get_options(kw))

if __name__ == '__main__':
    from paste import httpserver
    httpserver.serve(app(None), host='0.0.0.0', port='6543')
    



import os

from ez_setup import use_setuptools
use_setuptools()

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.txt')).read()
CHANGES = open(os.path.join(here, 'CHANGES.txt')).read()

setup(name='bestappever',
      version='0.1',
      description='An example application which uses repoze.bfg',
      long_description=README + '\n\n' +  CHANGES,
      classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
        ],
      author='Christian Scholz',
      author_email='cs@comlounge.net',
      url='http://mrtopf.de/blog/tutorials/a-first-look-at-repozebfg/',
      keywords='web wsgi bfg zope example',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
            'repoze.bfg',
            ],
      tests_require=[
            'repoze.bfg',
            ],
      test_suite="bestappever",
      entry_points = """\
      [paste.app_factory]
      app = bestappever.run:app
      """
      )




from zope.interface import Interface
from zope.interface import implements
from zope.location.interfaces import ILocation

class IMyModel(Interface):
    pass

class MyModel(object):
    implements(IMyModel, ILocation)

    __name__ = None
    __parent__ = None

    def __getitem__(self, name):
        return MyModel()

    def absolute_path(self):
        p = []
        node = self
        while node.__name__ is not None:
            p.append(node.__name__)
            node = node.__parent__
        p.reverse()
        return "/".join(p)

root = MyModel()

def get_root(environ):
    return root
